#[repr(transparent)]pub struct Ctrl1(pub u32);Expand description
Control Register 1 SFR
Tuple Fields
0: u32Implementations
Sourceimpl Ctrl1
impl Ctrl1
Sourcepub const fn read_index(&self) -> u8
pub const fn read_index(&self) -> u8
Index status, Writing an index value to this register will request the block to return the lock status of this index.
Sourcepub const fn set_read_index(&mut self, val: u8)
pub const fn set_read_index(&mut self, val: u8)
Index status, Writing an index value to this register will request the block to return the lock status of this index.
Sourcepub const fn reserved15(&self) -> u8
pub const fn reserved15(&self) -> u8
Reserved for Future Use
Sourcepub const fn set_reserved15(&mut self, val: u8)
pub const fn set_reserved15(&mut self, val: u8)
Reserved for Future Use
Sourcepub const fn set_wr_en_1(&mut self, val: u8)
pub const fn set_wr_en_1(&mut self, val: u8)
Write Enable One
Sourcepub const fn set_sfr_lock(&mut self, val: u8)
pub const fn set_sfr_lock(&mut self, val: u8)
LOCK register for GLIKEY
Sourcepub const fn reserved31(&self) -> u16
pub const fn reserved31(&self) -> u16
Reserved for Future Use
Sourcepub const fn set_reserved31(&mut self, val: u16)
pub const fn set_reserved31(&mut self, val: u16)
Reserved for Future Use